@@ -3,7 +3,8 @@ import inspect
 from functools import wraps
 from string import Formatter
 from pydantic.main import BaseModel
-from easi_py_common.client.rest_client import RestClient, DST_MODE_SERVICE
+
+from easi_py_common.client.rest_client import RestClient, RestClientResponseDecoder
 
 service_endpoint = {}
 
@@ -14,13 +15,13 @@ HTTP_METHOD_DELETE = 'DELETE'
 
 
 def service_client(url, timeout=(5, 5), http_adapter=None, before_request=None,
-                   dst_mode=DST_MODE_SERVICE):
+                   response_decoder: RestClientResponseDecoder = None):
     def wrapper(f):
         key = '{}.{}'.format(f.__module__, f.__name__)
 
         service_endpoint[key] = RestClient(
             url, timeout=timeout, http_adapter=http_adapter, before_request=before_request,
-            dst_mode=dst_mode)
+            response_decoder=response_decoder)
 
         @wraps(f)
         def wrapped(*args, **kwargs):
@@ -40,6 +41,7 @@ def service_mapping(uri, method, timeout=None, data_by_alias: bool = True, data_
 
         dst = full_arg_spec.annotations.get('return')
         has_format_names = [fn for _, fn, _, _ in Formatter().parse(uri) if fn is not None]
+        has_format_names.append('self')  # 参数列表过滤self
 
         def __get_request_params(named_args):
             request_named_args = {k: v for k, v in named_args.items() if k not in has_format_names}
